==> ansela_0.6-2.tar.gz: ansela-0.6/src/opt/anselA/core/buttons.py <==
from PyQt4.QtCore import pyqtSignature


from files import *
from filters.bw import *
from filters.colors import *
from filters.histogram import *
from filters.imageExif import *
from filters.levels import *
from filters.rotate import *
from filters.simple import *

@pyqtSignature("")
def ApplyGo(self):
    if (self.core.valCurTab == 1):
        Convert_BW(self, self.core.current.image, self.core.valBW, True)
    elif (self.core.valCurTab == 0):
        Simple_Adjustments(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 3):
        Adjust_ColorLevel(self, self.core.current.image, True)
    elif (self.core.valCurTab == 4):
        raise NotImplementedError
    elif (self.core.valCurTab == 5):
        RotateApply(self,  self.core.valRot)

    SlidersReset(self)
    FileImageRefresh(self)
    self.ShowApply(False)

    
    
@pyqtSignature("Self, Int, Int, QLabel")
def cSlide_ShiftValue(self, change, coreVal, qTextbox,  qSlider):
    coreVal  = coreVal + change
    qTextbox.setText(str(coreVal))
    qSlider.setValue(coreVal)
    
    return coreVal
    
    
@pyqtSignature("Self, Int, Int, QLabel")
def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider):
    coreVal  = value
    qTextbox.setText(str(coreVal))
    if  (self.core.displayUpdating == False):    
        Adjust_ColorLevel(self, self.core.current.thumb, False)
        
    return coreVal
    

@pyqtSignature("")
def SlidersReset(self):
    self.core.displayUpdating = True
    self.cSlide_B.setValue(0)
    self.cSlide_Br.setValue(0)
    self.cSlide_Co.setValue(0)
    self.cSlide_G.setValue(0)
    self.cSlide_Hi.setValue(0)
    self.cSlide_Mi.setValue(0)
    self.cSlide_R.setValue(0)
    self.cSlide_Sa.setValue(0)
    self.cSlide_Sh.setValue(0)
    self.cSlide_Sw.setValue(0)
    self.core.displayUpdating = False
              
      
#def on_cSlide_B_sliderReleased(self):
#    self.core.valB = value
#    self.lcdB.setText(str(self.core.valB))
#    self.LevelApply(self.core.current.thumb,  False)
#        
#def on_btnSlide_H_up_pressed(self):
#    self.core.valB = value
#    self.lcdB.setText(str(self.core.valB))
#    self.LevelApply(self.core.current.thumb,  False)
#    
#def on_btnSlide_H_dn_pressed(self):
#    
#def on_btnSlide_Mid_dn_pressed(self):
#    
#def on_btnSlide_Mid_up_pressed(self):
#
#def on_btnSlide_Sha_dn_pressed(self):
#
#def on_btnSlide_Sha_up_pressed(self):
#
#def on_btnSlide_Co_dn_pressed(self):
#
#def on_btnSlide_Co_up_pressed(self):
#
#def on_btnSlide_Sa_up_pressed(self):
#
#def on_btnSlide_Sa_dn_pressed(self):
#
#def on_btnSlide_Br_dn_pressed(self):
#
#def on_btnSlide_Br_up_pressed(self):
#
#def on_btnSlide_Sh_dn_pressed(self):
#
#def on_btnSlide_sh_up_pressed(self):
#


#
#def on_btnSlide_G_up_pressed(self):
#
#def on_btnSlide_G_dn_pressed(self):

==> ansela_0.7-3.tar.gz: ansela-0.7/src/opt/anselA/core/buttons.py <==
from PyQt4.QtCore import pyqtSignature
from core import *
from files import *
from filters.bw import *
from filters.colors import *
from filters.histogram import *
from filters.imageExif import *
from filters.levels import *
from filters.rotate import *
from filters.simple import *

#######################################
#   Apply
#######################################
def ApplyGo(self):
    ToggleThumbWait(self, True)
    if (self.core.valCurTab == 1):
        Convert_BW(self, self.core.current.image, self.core.valBW, True)
    elif (self.core.valCurTab == 2):
        Simple_Adjustments(self, self.core.current.image, "Any", True)
    elif (self.core.valCurTab == 3):
        Adjust_ColorLevel(self, self.core.current.image, True)
    elif (self.core.valCurTab == 4):
        Adjust_ToneLevel(self, self.core.current.image, True)
    elif (self.core.valCurTab == 5):
        RotateApply(self,  self.core.valRot)

    SlidersReset(self)
    FileImageRefresh(self)
    ShowApply(self, False)
    ToggleThumbWait(self, False)
    
def cSlide_ShiftValue(self, change, coreVal, qTextbox,  qSlider):
    coreVal  = coreVal + change
    qTextbox.setText(str(coreVal))
    qSlider.setValue(coreVal)
    return coreVal
    
def cSlide_SetValue(self, value, coreVal, qTextbox,  qSlider):
    coreVal  = value
    tab =self.core.GetCurrentTab(self)
    qTextbox.setText(str(coreVal))
    if  (self.core.displayUpdating == False):
        if (tab == 2):
            Simple_Adjustments(self, self.core.current.thumb, "Any",  False)
        elif (tab == 3):
            Adjust_ColorLevel(self, self.core.current.thumb,  False)
        elif (tab == 4):
            Adjust_ToneLevel(self, self.core.current.thumb,  False)
    return coreVal

def SlidersReset(self):
    self.core.displayUpdating = True
    self.cSlide_B.setValue(0)
    self.cSlide_Br.setValue(0)
    self.cSlide_Co.setValue(0)
    self.cSlide_G.setValue(0)
    self.cSlide_Hi.setValue(0)
    self.cSlide_Mi.setValue(0)
    self.cSlide_R.setValue(0)
    self.cSlide_Sa.setValue(0)
    self.cSlide_Sh.setValue(0)
    self.cSlide_Sw.setValue(0)
    self.core.displayUpdating = False
              
      
    #######################################
    #   Undo
    #######################################
        
def UndoGo(self):
    self.core.UndoImage_Set()
    self.loadUndoImages()
    
    ToggleThumbWait(self, True)
    FullScreenToggle(self, False)
    FileImageRefresh(self, 0)
        
    self.btnApplyUndo.setText(":"+str(self.core.undoCount))
    ToggleThumbWait(self, False)
        
        
        
        
        
        
        
        
        
        
        
        
#def on_cSlide_B_sliderReleased(self):
#    self.core.valB = value
#    self.lcdB.setText(str(self.core.valB))
#    self.LevelApply(self.core.current.thumb,  False)
#        
#def on_btnSlide_H_up_pressed(self):
#    self.core.valB = value
#    self.lcdB.setText(str(self.core.valB))
#    self.LevelApply(self.core.current.thumb,  False)
#    
#def on_btnSlide_H_dn_pressed(self):
#    
#def on_btnSlide_Mid_dn_pressed(self):
#    
#def on_btnSlide_Mid_up_pressed(self):
#
#def on_btnSlide_Sha_dn_pressed(self):
#
#def on_btnSlide_Sha_up_pressed(self):
#
#def on_btnSlide_Co_dn_pressed(self):
#
#def on_btnSlide_Co_up_pressed(self):
#
#def on_btnSlide_Sa_up_pressed(self):
#
#def on_btnSlide_Sa_dn_pressed(self):
#
#def on_btnSlide_Br_dn_pressed(self):
#
#def on_btnSlide_Br_up_pressed(self):
#
#def on_btnSlide_Sh_dn_pressed(self):
#
#def on_btnSlide_sh_up_pressed(self):
#


#
#def on_btnSlide_G_up_pressed(self):
#
#def on_btnSlide_G_dn_pressed(self):
